@@ -14,6 +14,7 @@
 
 mod blueprint;
 mod bpf;
+mod cpu_info;
 mod debugfs;
 mod error;
 mod maps;
@@ -29,7 +30,6 @@ use blueprint::ProgramObject;
 use bpf::{
     constant::bpf_map_type,
     syscall::{self, bpf_map_update_elem},
-    BpfAttr, MapConfig, SizedBpfAttr,
 };
 use debugfs::{get_debugfs_mount_point, mount_debugfs_if_missing};
 use maps::perf_map_poller::PerfMapPoller;
@@ -474,7 +474,7 @@ impl<'a> Program<'a> {
         let is_return = self.kind == Some(ProgramType::Uretprobe);
         let pid = self.pid.unwrap_or(-1);
 
-        maps::get_cpus()?
+        cpu_info::online()?
             .into_iter()
             .flat_map(|cpu| {
                 self.attach_points
@@ -811,6 +811,8 @@ impl ProgramVersion<'_> {
 
         let mut perfmap_opts = None;
 
+        let perfmap_entries = cpu_info::max_possible_index()? as u32 + 1;
+
         for program_object in matching_blueprints.iter_mut() {
             for name in program_object.required_maps().iter() {
                 let map = program_blueprint
@@ -827,16 +829,15 @@ impl ProgramVersion<'_> {
                     })?;
 
                 if !loaded_maps.contains(&map.name) {
-                    let sized_attr = SizedBpfAttr {
-                        bpf_attr: BpfAttr {
-                            map_config: MapConfig::from(map.definition),
-                        },
-                        size: 20,
-                    };
                     match map.definition.map_type {
                         bpf_map_type::BPF_MAP_TYPE_PERF_EVENT_ARRAY => {
-                            let fd =
-                                unsafe { syscall::bpf_map_create_with_sized_attr(sized_attr)? };
+                            if map.definition.max_entries == 0 {
+                                map.definition.max_entries = perfmap_entries
+                            };
+
+                            let fd = unsafe {
+                                syscall::bpf_map_create_with_sized_attr(map.definition.into())?
+                            };
                             self.fds.insert(fd);
                             map.set_loaded(fd);
                             program_object.fixup_map_relocation(fd, map)?;
@@ -930,8 +931,9 @@ impl ProgramVersion<'_> {
                             };
                         }
                         _ => {
-                            let fd =
-                                unsafe { syscall::bpf_map_create_with_sized_attr(sized_attr)? };
+                            let fd = unsafe {
+                                syscall::bpf_map_create_with_sized_attr(map.definition.into())?
+                            };
                             self.fds.insert(fd);
                             map.set_loaded(fd);
                             program_object.fixup_map_relocation(fd, map)?;
